==> elgg-1.12.12.zip: elgg-1.12.12/mod/groups/languages/eu_es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Taldeak",
	'groups:owned' => "Nireak diren taldeak",
	'groups:owned:user' => '%s diren taldeak',
	'groups:yours' => "Nire taldeak",
	'groups:user' => "%s-ren taldeak",
	'groups:all' => "Talde guztiak",
	'groups:add' => "Talde berri bat sortu",
	'groups:edit' => "Taldea editatu",
	'groups:delete' => 'Taldea ezabatu',
	'groups:membershiprequests' => 'Batzeko eskaerak kudeatu',
	'groups:membershiprequests:pending' => 'Batzeko eskaerak kudeatu (%s)',
	'groups:invitations' => 'Talde gonbidapenak',
	'groups:invitations:pending' => 'Talde gonbidapenak (%s)',

	'groups:icon' => 'Taldeko ikonoa (hutsik utzi ez aldatzeko)',
	'groups:name' => 'Talde izena',
	'groups:username' => 'Taldearen izen laburra (URLetan erakutsiko da, alfanumerikoa, karaktereak bakarrik)',
	'groups:description' => 'Deskribapena',
	'groups:briefdescription' => 'Deskribapen laburra',
	'groups:interests' => 'Etiketak',
	'groups:website' => 'Webgunea',
	'groups:members' => 'Taldeko kideak',
	'groups:my_status' => 'Nire egoera',
	'groups:my_status:group_owner' => 'Talde honen jabea zara',
	'groups:my_status:group_member' => 'Talde honetan zaude',
	'groups:subscribed' => 'Talde jakinarazpenak piztuta',
	'groups:unsubscribed' => 'Talde jakinarazpenak itzalita',

	'groups:members:title' => '%s-eko kideak',
	'groups:members:more' => "Kide guztiak ikusi",
	'groups:membership' => "Taldeko kideen baimenak",
	'groups:content_access_mode' => "Taldeko edukiaren erabilerraztasuna",
	'groups:content_access_mode:warning' => "Oharra: Ezarpen hau aldatzeak ez du existitzen duen taldeko edukiaren baimenak aldatuko.",
	'groups:content_access_mode:unrestricted' => "Ez mugatua - Atzipenak eduki-mailaren ezarpenen araberakoa da",
	'groups:content_access_mode:membersonly' => "Kideak bakarrik - Kide ez diren erabiltzaileak ez dute inoiz taldeko edukira atzipena izango",
	'groups:access' => "Atzipen baimenak",
	'groups:owner' => "Jabea",
	'groups:owner:warning' => "Oharra: Balio hau aldatzen baduzu, ez zara gehiago talde honetako jabea izango.",
	'groups:widget:num_display' => 'Erakutsiko den talde kopurua',
	'groups:widget:membership' => 'Taldeko kide izatea',
	'groups:widgets:description' => 'Kide zaren taldeak erakutsi zure profilean',

	'groups:widget:group_activity:title' => 'Taldeko aktibitatea',
	'groups:widget:group_activity:description' => 'Zure taldeetako baten aktibitatea ikusi',
	'groups:widget:group_activity:edit:select' => 'Talde bat aukeratu',
	'groups:widget:group_activity:content:noactivity' => 'Ez dago aktibitaterik talde honetan',
	'groups:widget:group_activity:content:noselect' => 'Widget hau editatu talde bat aukeratzeko',

	'groups:noaccess' => 'Atzipenik ez taldera',
	'groups:permissions:error' => 'Ez duzu baimenik honetarako',
	'groups:ingroup' => 'taldean',
	'groups:cantcreate' => 'Ezin duzu talderik sortu. Administratzaileak bakarrik egin dezake.',
	'groups:cantedit' => 'Ezin duzu talde hau editatu',
	'groups:saved' => 'Taldea gordeta',
	'groups:save_error' => 'Ezinezkoa da taldea gordetzea',
	'groups:featured' => 'Nabarmendutako taldeak',
	'groups:makeunfeatured' => 'Ez nabarmendu',
	'groups:makefeatured' => 'Nabarmendua egin',
	'groups:featuredon' => '%s orain nabarmendutako talde bat da.',
	'groups:unfeatured' => '%s nabarmendutako taldeetatik kendu da.',
	'groups:featured_error' => 'Talde okerra.',
	'groups:nofeatured' => 'Ez dago nabarmendutako talderik',
	'groups:joinrequest' => 'Talde kide izateko eskatu',
	'groups:join' => 'Taldera batu',
	'groups:leave' => 'Taldea utzi',
	'groups:invite' => 'Lagunak gonbidatu',
	'groups:invite:title' => 'Lagunak gonbidatu talde honetara',
	'groups:inviteto' => "Lagunak '%s'-era gonbidatu",
	'groups:nofriends' => "Ez zaizu lagunik geratzen talde honetara gonbidatu ez duzuna.",
	'groups:nofriendsatall' => 'Ez duzu lagunik gonbidatzeko!',
	'groups:viagroups' => "taldeen bitartez",
	'groups:group' => "Taldea",
	'groups:search:tags' => "etiketa",
	'groups:search:title' => "'%s' etiketa dituen taldeen bilaketa",
	'groups:search:none' => "Ez dira bat datozen talderik aurkitu",
	'groups:search_in_group' => "Talde honetan bilatu",
	'groups:acl' => "Taldea: %s",

	'discussion:topic:notify:summary' => 'Eztabaida gai berri bat %s deitua',
	'discussion:topic:notify:subject' => 'Eztabaida gai berria: %s',
	'discussion:topic:notify:body' =>
'%s-ek eztabaida gai berri bat gehitu du %s taldean:

Izenburua: %s

%s

Ikusi eta erantzun eztabaida gaiari:
%s
',

	'discussion:reply:notify:summary' => 'Erantzun berria gaian: %s',
	'discussion:reply:notify:subject' => 'Erantzun berria gaian: %s',
	'discussion:reply:notify:body' =>
'%s-ek %s eztabaida gaian erantzun du %s taldean:

%s

Ikusi eta erantzun eztabaidan:
%s
',

	'groups:activity' => "Taldeko aktibitatea",
	'groups:enableactivity' => 'Taldeko aktibitatea gaitu',
	'groups:activity:none' => "Ez dago taldeko aktibitaterik oraindik",

	'groups:notfound' => "Taldea ez da aurkitu",
	'groups:notfound:details' => "Eskatutako taldea ez da existitzen edo ez duzu atzipena bertara",

	'groups:requests:none' => 'Ez dago talde kide izateko eskaerarik orain.',

	'groups:invitations:none' => 'Ez dago gonbidapenik orain.',

	'item:object:groupforumtopic' => "Eztabaida gaiak",
	'item:object:discussion_reply' => "Eztabaida erantzunak",

	'groupforumtopic:new' => "Eztabaida bidalketa berria",

	'groups:count' => "taldeak sortuta",
	'groups:open' => "talde irekia",
	'groups:closed' => "talde itxia",
	'groups:member' => "kideak",
	'groups:searchtag' => "Etiketaren bidez bilatu taldeak",

	'groups:more' => 'Talde gehiago',
	'groups:none' => 'Ez dago talderik',

	/**
	 * Access
	 */
	'groups:access:private' => 'Itxita - Erabiltzaileak gonbidatuak izan behar dira',
	'groups:access:public' => 'Irekia - Edozein erabiltzaile batu daiteke',
	'groups:access:group' => 'Taldeko kideak bakarrik',
	'groups:closedgroup' => "Talde honen kide izateko aukera itxita dago.",
	'groups:closedgroup:request' => 'Gehitzeko izateko galdetzeko, klikatu "Talde kide izateko eskatu" menu elementuan.',
	'groups:closedgroup:membersonly' => "Talde honen kide izatea itxita dago eta bere edukia kideentzako bakarrik dago eskuragarri.",
	'groups:opengroup:membersonly' => "Taldeko edukia kideentzako bakarrik dago atzigarri.",
	'groups:opengroup:membersonly:join' => 'Kide izateko, klikatu "Batu taldera" menu elementuan.',
	'groups:visibility' => 'Nork ikusi dezake talde hau?',

	/**
	 * Group tools
	 */
	'groups:enableforum' => 'Talde eztabaida gaitu',
	'groups:lastupdated' => 'Azken eguneraketa: %s Nork: %s',
	'groups:lastcomment' => 'Azken iruzkina: %s Nork: %s',

	/**
	 * Group discussion
	 */
	'discussion' => 'Eztabaida',
	'discussion:add' => 'Eztabaida gaia gehitu',
	'discussion:latest' => 'Azken eztabaida',
	'discussion:group' => 'Talde eztabaida',
	'discussion:none' => 'Eztabaidarik ez',
	'discussion:reply:title' => 'Nork erantzunda %s',

	'discussion:topic:created' => 'Eztabaida gaia sortua izan da.',
	'discussion:topic:updated' => 'Eztabaida gaia eguneratua izan da.',
	'discussion:topic:deleted' => 'Eztabaida gaia ezabatua izan da.',

	'discussion:topic:notfound' => 'Ez da eztabaida gaia aurkitu',
	'discussion:error:notsaved' => 'Ezinezkoa gaia gordetzea',
	'discussion:error:missing' => 'Izenburu eta mezua beharrezko eremuak dira',
	'discussion:error:permissions' => 'Ez duzu baimenik ekintza hau burutzeko',
	'discussion:error:notdeleted' => 'Ezin izan da eztabaida gaia ezabatu',

	'discussion:reply:edit' => 'Erantzuna editatu',
	'discussion:reply:deleted' => 'Eztabaida erantzuna ezabatua izan da.',
	'discussion:reply:error:notfound' => 'Ez da eztabaida erantzuna aurkitu',
	'discussion:reply:error:notfound_fallback' => "Barkatu, ezin dugu zehaztutako erantzuna bilatu, baina eztabaida gai originalera berbidaliko dizugu.",
	'discussion:reply:error:notdeleted' => 'Ezin izan da eztabaida erantzuna ezabatu',

	'discussion:search:title' => 'Gaian erantzun: %s',
	
	'admin:groups' => 'Taldeak',

	'reply:this' => 'Honi erantzun',

	'group:replies' => 'Erantzunak',
	'groups:forum:created' => '%s sortua %d iruzkinekin',
	'groups:forum:created:single' => '%s sortua %d erantzunekin',
	'groups:forum' => 'Eztabaida',
	'groups:addtopic' => 'Gai bat gehitu',
	'groups:forumlatest' => 'Azken eztabaida',
	'groups:latestdiscussion' => 'Azken eztabaida',
	'groupspost:success' => 'Zure erantzuna arrakastaz bidali da.',
	'groupspost:failure' => 'Arazo bat egon da zure erantzuna bidaltzean',
	'groups:alldiscussion' => 'Azken eztabaida',
	'groups:edittopic' => 'Gaia editatu',
	'groups:topicmessage' => 'Gaiaren mezua',
	'groups:topicstatus' => 'Gaiaren egoera',
	'groups:reply' => 'Iruzkin bat bidali',
	'groups:topic' => 'Gaia',
	'groups:posts' => 'Bidalketak',
	'groups:lastperson' => 'Azken pertsona',
	'groups:when' => 'Noiz',
	'grouptopic:notcreated' => 'Ez dira gairik sortu.',
	'groups:topicclosed' => 'Itxita',
	'grouptopic:created' => 'Zure gaia sortua izan da.',
	'groups:topicsticky' => 'Itsaskorra',
	'groups:topicisclosed' => 'Eztabaida itxita dago.',
	'groups:topiccloseddesc' => 'Eztabaida itxita dago eta ez du iruzkin berririk onartzen.',
	'grouptopic:error' => 'Zure taldeko gaia ezin izan da sortu. Mesedez saiatu berriz edo sistemako administratzailearekin kontaktuan jarri.',
	'groups:forumpost:edited' => "Foroko bidalketa arrakastaz editatu duzu.",
	'groups:forumpost:error' => "Arazo bat egon da foroko bidalketa editatzean.",

	'groups:privategroup' => 'Talde hau itxita dago. Eskatu kide izateko.',
	'groups:notitle' => 'Taldeak izenburu bat izan behar du',
	'groups:cantjoin' => 'Ezin da taldera batu',
	'groups:cantleave' => 'Ezin da taldea utzi',
	'groups:removeuser' => 'Taldetik kendu',
	'groups:cantremove' => 'Ezin da erabiltzailea taldetik kendu',
	'groups:removed' => '%s arrakastaz kendu da taldetik',
	'groups:addedtogroup' => 'Arrakastaz gehitu da erabiltzailea taldera',
	'groups:joinrequestnotmade' => 'Ezin da taldera batzeko eskaera egin',
	'groups:joinrequestmade' => 'Taldera batzeko eskaera eginda',
	'groups:joined' => 'Arrakastaz batu da taldera!',
	'groups:left' => 'Arrakastaz utzi da taldea',
	'groups:notowner' => 'Barkatu, ez zara talde honetako jabea.',
	'groups:notmember' => 'Barkatu, ez zara  talde honetako kidea.',
	'groups:alreadymember' => 'Jada bazara talde honetako kidea!',
	'groups:userinvited' => 'Erabiltzailea gonbidatua izan da.',
	'groups:usernotinvited' => 'Erabiltzailea ezin izan da gonbidatu.',
	'groups:useralreadyinvited' => 'Erabiltzailea jada gonbidatua izan da',
	'groups:invite:subject' => "%s %s taldera batzeko gonbidatua izan da!",
	'groups:updated' => "Azken erantzuna %s %s",
	'groups:started' => "Nork hasita: %s",
	'groups:joinrequest:remove:check' => 'Ziur al zaude batzeko eskaera hau ezabatu nahi duzula?',
	'groups:invite:remove:check' => 'Ziur al zaude gonbidapen hau ezabatu nahi duzula?',
	'groups:invite:body' => "Kaixo %s,

%s-ek '%s' taldera batzeko gobidatu zaitu. Klikatu hurrengo estekan zure gonbidapenak ikusteko:

%s",

	'groups:welcome:subject' => "Ongi etorri %s taldera!",
	'groups:welcome:body' => "Kaixo %s!

Orain '%s' taldeko kidea zara! Klikatu hurrengo estekan idazten hasteko!

%s",

	'groups:request:subject' => "%s-ek %s batzeko eskatu du",
	'groups:request:body' => "Kaixo %s,

%s-ek '%s' taldera batzeko eskaera egin du. Klikatu hurrengo estekan bere profila ikusteko:

%s

edo klikatu hurrengoan taldeko eskaerak ikusteko:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s-ek %s taldea sortu du',
	'river:join:group:default' => '%s %s taldera batu da',
	'river:create:object:groupforumtopic' => '%s-ek %s eztabaida gai berria gehitu du',
	'river:reply:object:groupforumtopic' => '%s-el %s eztabaida gaian erantzun du',
	'river:reply:view' => 'erantzuna ikusi',

	'groups:nowidgets' => 'Ez da widgetik zehaztu talde honetarako.',


	'groups:widgets:members:title' => 'Taldeko kideak',
	'groups:widgets:members:description' => 'Taldeko kideen zerrenda.',
	'groups:widgets:members:label:displaynum' => 'Taldeko kideen zerrenda.',
	'groups:widgets:members:label:pleaseedit' => 'Mesedez, widget hau konfiguratu.',

	'groups:widgets:entities:title' => "Objektuak taldean",
	'groups:widgets:entities:description' => "Talde honetan gordetako objektuak zerrendatu",
	'groups:widgets:entities:label:displaynum' => 'Talde honetan objektuak zerrendatu.',
	'groups:widgets:entities:label:pleaseedit' => 'Mesedez, widget hau konfiguratu.',

	'groups:forumtopic:edited' => 'Foroko gaia arrakastaz editatu da.',

	'groups:allowhiddengroups' => 'Nahi al dituzu talde pribatuak (ikusezina) baimendu?',
	'groups:whocancreate' => 'Nork sortu ditzake talde berriak?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Taldea eta taldeko edukia ezabatuta',
	'group:notdeleted' => 'Taldea ezin izan da ezabatu',

	'group:notfound' => 'Ezin izan da talde bilatu',
	'grouppost:deleted' => 'Taldeko bidalketak arrakastaz ezabatu dira',
	'grouppost:notdeleted' => 'Ezin izan dira taldeko bidalketak ezabatu',
	'groupstopic:deleted' => 'Gai ezabatuta',
	'groupstopic:notdeleted' => 'Gai ez da ezabatu',
	'grouptopic:blank' => 'Ez dago gairik',
	'grouptopic:notfound' => 'Ezin izan da gaia bilatu',
	'grouppost:nopost' => 'Bidalketa hutsik dago',
	'groups:deletewarning' => "Ziur al zaude talde hau ezabatu nahi duzula? Ez dago atzera bueltarik ondoren!",

	'groups:invitekilled' => 'Gonbidapena ezabatua izan da.',
	'groups:joinrequestkilled' => 'Batzeko eskaera ezabatua izan da.',
	'groups:error:addedtogroup' => "Ezin izan da %s taldera gehitu",
	'groups:add:alreadymember' => "%s jada bada taldeko kidea",

	/**
	 * ecml
	 */
	'groups:ecml:discussion' => 'Taldeko eztabaidak',
	'groups:ecml:groupprofile' => 'Taldeko profilak',
);

==> elgg-2.3.5.zip: elgg-2.3.5/mod/groups/languages/eu_es.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Taldeak",
	'groups:owned' => "Nireak diren taldeak",
	'groups:owned:user' => '%s diren taldeak',
	'groups:yours' => "Nire taldeak",
	'groups:user' => "%s-ren taldeak",
	'groups:all' => "Talde guztiak",
	'groups:add' => "Talde berri bat sortu",
	'groups:edit' => "Taldea editatu",
	'groups:delete' => 'Taldea ezabatu',
	'groups:membershiprequests' => 'Batzeko eskaerak kudeatu',
	'groups:membershiprequests:pending' => 'Batzeko eskaerak kudeatu (%s)',
	'groups:invitations' => 'Talde gonbidapenak',
	'groups:invitations:pending' => 'Talde gonbidapenak (%s)',

	'groups:icon' => 'Taldeko ikonoa (hutsik utzi ez aldatzeko)',
	'groups:name' => 'Talde izena',
	'groups:username' => 'Taldearen izen laburra (URLetan erakutsiko da, alfanumerikoa, karaktereak bakarrik)',
	'groups:description' => 'Deskribapena',
	'groups:briefdescription' => 'Deskribapen laburra',
	'groups:interests' => 'Etiketak',
	'groups:website' => 'Webgunea',
	'groups:members' => 'Taldeko kideak',
	'groups:my_status' => 'Nire egoera',
	'groups:my_status:group_owner' => 'Talde honen jabea zara',
	'groups:my_status:group_member' => 'Talde honetan zaude',
	'groups:subscribed' => 'Group notifications are on',
	'groups:unsubscribed' => 'Group notifications are off',

	'groups:members:title' => '%s-eko kideak',
	'groups:members:more' => "Kide guztiak ikusi",
	'groups:membership' => "Taldeko kideen baimenak",
	'groups:content_access_mode' => "Taldeko edukiaren erabilerraztasuna",
	'groups:content_access_mode:warning' => "Oharra: Ezarpen hau aldatzeak ez du existitzen duen taldeko edukiaren baimenak aldatuko.",
	'groups:content_access_mode:unrestricted' => "Ez mugatua - Atzipenak eduki-mailaren ezarpenen araberakoa da",
	'groups:content_access_mode:membersonly' => "Kideak bakarrik - Kide ez diren erabiltzaileak ez dute inoiz taldeko edukira atzipena izango",
	'groups:access' => "Atzipen baimenak",
	'groups:owner' => "Jabea",
	'groups:owner:warning' => "Oharra: Balio hau aldatzen baduzu, ez zara gehiago talde honetako jabea izango.",
	'groups:widget:num_display' => 'Erakutsiko den talde kopurua',
	'groups:widget:membership' => 'Taldeko kide izatea',
	'groups:widgets:description' => 'Kide zaren taldeak erakutsi zure profilean',

	'groups:widget:group_activity:title' => 'Taldeko aktibitatea',
	'groups:widget:group_activity:description' => 'Zure taldeetako baten aktibitatea ikusi',
	'groups:widget:group_activity:edit:select' => 'Talde bat aukeratu',
	'groups:widget:group_activity:content:noactivity' => 'Ez dago aktibitaterik talde honetan',
	'groups:widget:group_activity:content:noselect' => 'Widget hau editatu talde bat aukeratzeko',

	'groups:noaccess' => 'Atzipenik ez taldera',
	'groups:ingroup' => 'taldean',
	'groups:cantcreate' => 'Ezin duzu talderik sortu. Administratzaileak bakarrik egin dezake.',
	'groups:cantedit' => 'Ezin duzu talde hau editatu',
	'groups:saved' => 'Taldea gordeta',
	'groups:save_error' => 'Ezinezkoa da taldea gordetzea',
	'groups:featured' => 'Nabarmendutako taldeak',
	'groups:makeunfeatured' => 'Ez nabarmendu',
	'groups:makefeatured' => 'Nabarmendua egin',
	'groups:featuredon' => '%s orain nabarmendutako talde bat da.',
	'groups:unfeatured' => '%s nabarmendutako taldeetatik kendu da.',
	'groups:featured_error' => 'Talde okerra.',
	'groups:nofeatured' => 'Ez dago nabarmendutako talderik',
	'groups:joinrequest' => 'Talde kide izateko eskatu',
	'groups:join' => 'Taldera batu',
	'groups:leave' => 'Taldea utzi',
	'groups:invite' => 'Lagunak gonbidatu',
	'groups:invite:title' => 'Lagunak gonbidatu talde honetara',
	'groups:inviteto' => "Lagunak '%s'-era gonbidatu",
	'groups:nofriends' => "Ez zaizu lagunik geratzen talde honetara gonbidatu ez duzuna.",
	'groups:nofriendsatall' => 'Ez duzu lagunik gonbidatzeko!',
	'groups:viagroups' => "taldeen bitartez",
	'groups:group' => "Taldea",
	'groups:search:tags' => "etiketa",
	'groups:search:title' => "'%s' etiketa dituen taldeen bilaketa",
	'groups:search:none' => "Ez dira bat datozen talderik aurkitu",
	'groups:search_in_group' => "Talde honetan bilatu",
	'groups:acl' => "Taldea: %s",

	'groups:activity' => "Taldeko aktibitatea",
	'groups:enableactivity' => 'Taldeko aktibitatea gaitu',
	'groups:activity:none' => "Ez dago taldeko aktibitaterik oraindik",

	'groups:notfound' => "Taldea ez da aurkitu",
	'groups:notfound:details' => "Eskatutako taldea ez da existitzen edo ez duzu atzipena bertara",

	'groups:requests:none' => 'Ez dago talde kide izateko eskaerarik orain.',

	'groups:invitations:none' => 'Ez dago gonbidapenik orain.',

	'groups:count' => "taldeak sortuta",
	'groups:open' => "talde irekia",
	'groups:closed' => "talde itxia",
	'groups:member' => "kideak",
	'groups:searchtag' => "Etiketaren bidez bilatu taldeak",

	'groups:more' => 'Talde gehiago',
	'groups:none' => 'Ez dago talderik',

	/**
	 * Access
	 */
	'groups:access:private' => 'Itxita - Erabiltzaileak gonbidatuak izan behar dira',
	'groups:access:public' => 'Irekia - Edozein erabiltzaile batu daiteke',
	'groups:access:group' => 'Taldeko kideak bakarrik',
	'groups:closedgroup' => "Talde honen kide izateko aukera itxita dago.",
	'groups:closedgroup:request' => 'Gehitzeko izateko galdetzeko, klikatu "Talde kide izateko eskatu" menu elementuan.',
	'groups:closedgroup:membersonly' => "Talde honen kide izatea itxita dago eta bere edukia kideentzako bakarrik dago eskuragarri.",
	'groups:opengroup:membersonly' => "Taldeko edukia kideentzako bakarrik dago atzigarri.",
	'groups:opengroup:membersonly:join' => 'Kide izateko, klikatu "Batu taldera" menu elementuan.',
	'groups:visibility' => 'Nork ikusi dezake talde hau?',

	/**
	 * Group tools
	 */
	'groups:lastupdated' => 'Azken eguneraketa: %s Nork: %s',
	'groups:lastcomment' => 'Azken iruzkina: %s Nork: %s',

	'admin:groups' => 'Taldeak',

	'groups:privategroup' => 'Talde hau itxita dago. Eskatu kide izateko.',
	'groups:notitle' => 'Taldeak izenburu bat izan behar du',
	'groups:cantjoin' => 'Ezin da taldera batu',
	'groups:cantleave' => 'Ezin da taldea utzi',
	'groups:removeuser' => 'Taldetik kendu',
	'groups:cantremove' => 'Ezin da erabiltzailea taldetik kendu',
	'groups:removed' => '%s arrakastaz kendu da taldetik',
	'groups:addedtogroup' => 'Arrakastaz gehitu da erabiltzailea taldera',
	'groups:joinrequestnotmade' => 'Ezin da taldera batzeko eskaera egin',
	'groups:joinrequestmade' => 'Taldera batzeko eskaera eginda',
	'groups:joined' => 'Arrakastaz batu da taldera!',
	'groups:left' => 'Arrakastaz utzi da taldea',
	'groups:notowner' => 'Barkatu, ez zara talde honetako jabea.',
	'groups:notmember' => 'Barkatu, ez zara  talde honetako kidea.',
	'groups:alreadymember' => 'Jada bazara talde honetako kidea!',
	'groups:userinvited' => 'Erabiltzailea gonbidatua izan da.',
	'groups:usernotinvited' => 'Erabiltzailea ezin izan da gonbidatu.',
	'groups:useralreadyinvited' => 'Erabiltzailea jada gonbidatua izan da',
	'groups:invite:subject' => "%s %s taldera batzeko gonbidatua izan da!",
	'groups:started' => "Nork hasita: %s",
	'groups:joinrequest:remove:check' => 'Ziur al zaude batzeko eskaera hau ezabatu nahi duzula?',
	'groups:invite:remove:check' => 'Ziur al zaude gonbidapen hau ezabatu nahi duzula?',
	'groups:invite:body' => "Kaixo %s,

%s-ek '%s' taldera batzeko gobidatu zaitu. Klikatu hurrengo estekan zure gonbidapenak ikusteko:

%s",

	'groups:welcome:subject' => "Ongi etorri %s taldera!",
	'groups:welcome:body' => "Kaixo %s!

Orain '%s' taldeko kidea zara! Klikatu hurrengo estekan idazten hasteko!

%s",

	'groups:request:subject' => "%s-ek %s batzeko eskatu du",
	'groups:request:body' => "Kaixo %s,

%s-ek '%s' taldera batzeko eskaera egin du. Klikatu hurrengo estekan bere profila ikusteko:

%s

edo klikatu hurrengoan taldeko eskaerak ikusteko:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s-ek %s taldea sortu du',
	'river:join:group:default' => '%s %s taldera batu da',

	'groups:nowidgets' => 'Ez da widgetik zehaztu talde honetarako.',


	'groups:widgets:members:title' => 'Taldeko kideak',
	'groups:widgets:members:description' => 'Taldeko kideen zerrenda.',
	'groups:widgets:members:label:displaynum' => 'Taldeko kideen zerrenda.',
	'groups:widgets:members:label:pleaseedit' => 'Mesedez, widget hau konfiguratu.',

	'groups:widgets:entities:title' => "Objektuak taldean",
	'groups:widgets:entities:description' => "Talde honetan gordetako objektuak zerrendatu",
	'groups:widgets:entities:label:displaynum' => 'Talde honetan objektuak zerrendatu.',
	'groups:widgets:entities:label:pleaseedit' => 'Mesedez, widget hau konfiguratu.',

	'groups:allowhiddengroups' => 'Nahi al dituzu talde pribatuak (ikusezina) baimendu?',
	'groups:whocancreate' => 'Nork sortu ditzake talde berriak?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Taldea eta taldeko edukia ezabatuta',
	'group:notdeleted' => 'Taldea ezin izan da ezabatu',

	'group:notfound' => 'Ezin izan da talde bilatu',
	'groups:deletewarning' => "Ziur al zaude talde hau ezabatu nahi duzula? Ez dago atzera bueltarik ondoren!",

	'groups:invitekilled' => 'Gonbidapena ezabatua izan da.',
	'groups:joinrequestkilled' => 'Batzeko eskaera ezabatua izan da.',
	'groups:error:addedtogroup' => "Ezin izan da %s taldera gehitu",
	'groups:add:alreadymember' => "%s jada bada taldeko kidea",

	/**
	 * ecml
	 */
	'groups:ecml:groupprofile' => 'Taldeko profilak',
);
